import Link from "next/link";
import { Metadata } from "next";

import { getPlaylist } from "@/lib/playlists";

import time from "@/lib/time";

interface PlaylistProps {
	params: {
		playlist_id: string;
	};
}

export async function generateMetadata({
	params,
}: PlaylistProps): Promise<Metadata> {
	const playlist = await getPlaylist(params.playlist_id);

	return {
		title: playlist.name,
	};
}

export default async function Playlist({ params }: PlaylistProps) {
	const playlist = await getPlaylist(params.playlist_id);

	return (
		<section>
			<header className="mb-12 flex items-center gap-8 border-b pb-12">
				<div className="h-48 w-48 rounded-md border bg-secondary" />
				<div className="flex flex-col gap-4">
					<h2 className="text-3xl font-bold">{playlist.name}</h2>
					<p className="text-secondary">
						Created by{" "}
						<Link
							className="font-bold text-primary hover:underline"
							href={`/users/${playlist.creator.id}`}
						>
							{playlist.creator.name}
						</Link>
					</p>
					<p className="text-xs uppercase tracking-widest text-secondary">
						{playlist.tracks_count} Tracks – {parseDuration(playlist.duration)}
					</p>
				</div>
			</header>

			<div className="overflow-hidden">
				<div className="playlist-row text-sm uppercase text-secondary">
					<span></span>
					<span>Title</span>
					<span>Artists</span>
					<span>Album</span>
					<span className="text-center">Date added</span>
					<span className="text-center">Time</span>
				</div>
				<div>
					{playlist.tracks.map((track) => {
						return (
							<div
								key={track.id}
								className="playlist-row h-[72px] cursor-pointer transition-colors hover:bg-secondary"
							>
								<div className="h-12 w-12 overflow-hidden rounded-md">
									<img src="https://via.placeholder.com/48" />
								</div>
								<div className="flex flex-col">
									<b className="text-lg">{track.title}</b>
								</div>
								<div>
									{track.artists.map((artist) => (
										<Link
											key={artist.id}
											href={`/artists/${artist.id}`}
											className="hover:underline"
										>
											{artist.title}
										</Link>
									))}
								</div>
								<Link href={`/albums/`}></Link>
								<span className="text-center text-sm">Nope</span>
								<span className="text-center text-sm">
									{parseDuration(track.duration_ms)}
								</span>
							</div>
						);
					})}
				</div>
			</div>
		</section>
	);
}

function parseDuration(duration_ms: number) {
	const duration = time.duration(duration_ms);

	const hours = duration.hours(),
		minutes = duration.minutes(),
		seconds = duration.seconds();

	let formatted = "";

	if (hours > 0) {
		formatted += `${hours}h `;
	}

	if (minutes > 0) {
		formatted += `${hours > 0 && minutes < 10 ? 0 : ""}${minutes}m `;
	}

	formatted += `${minutes > 0 && seconds < 10 ? 0 : ""}${seconds}s`;

	return formatted;
}
